@@ -124,9 +124,6 @@ class globalvars:
             f.write('CHEMDBDIR=\n')
             f.close()
 
-        
-
-
         # global settings
         self.homedir = homedir
         self.nosmiles = 0 # number of smiles ligands
@@ -134,6 +131,9 @@ class globalvars:
         self.generated = 0 
         self.debug = False # additional output for debuggin
         self.remHsmarts = ["O=CN","O=CO","n","N=CN","nN"] # remove Hs from connecting atoms within these SMARTS patterns
+        # default geometries for each coordination number if none specified
+        self.defaultgeometry = {6:('oct','octahedral'),5:('tbp','trigonal bipyramidal'),4:('sqp','square planar'),3:('trigonal planar','tpl'),2:('linear','li'),1:('one','one')}
+        self.defaultoxstate = {'au':'I','gold':'I','scandium':'III','sc':'III','ti':'IV','titanium':'IV'}
     def amass(self):
         return amassdict
     def metals(self):
